==> crowdstrike_falconpy_dev-1.0.5.dev4-py3-none-any.whl: crowdstrike_falconpy_dev-1.0.5.dev4.dist-info/AUTHORS.md <==
![CrowdStrike FalconPy](https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/cs-logo.png)

[![Twitter URL](https://img.shields.io/twitter/url?label=Follow%20%40CrowdStrike&style=social&url=https%3A%2F%2Ftwitter.com%2FCrowdStrike)](https://twitter.com/CrowdStrike)

# FalconPy Project Authors
The FalconPy project exists to enable developer interactions with the CrowdStrike Falcon API. Designed to be easy to integrate and use within your Python projects, the library is released under the [Unlicense](LICENSE) license. Developed and maintained by a diverse group of security architects, engineers and specialists, FalconPy has received multiple contributions from the community at large.

| Name | |
| :--- | :--- |
| Joshua Hiller, `@jshcodes` | [Lord of the FalconPys](https://xkcd.com/1604/) [:fly:](https://xkcd.com/1856/) |
| Dixon Styres, `@crowdstrikedcs` | [Author](https://xkcd.com/1646/) |
| Devin Cargill, `@dcargs` | [Author](https://xkcd.com/722/) |

<BR/>

[![Maintainers](https://img.shields.io/badge/-Maintainers-lightgreen?style=for-the-badge)](#maintainers)
[![Contributors](https://img.shields.io/badge/-Contributors-tan?style=for-the-badge)](#contributors)
[![Sponsors](https://img.shields.io/badge/-Sponsors-silver?style=for-the-badge)](#sponsors)
[![Get on the list](https://img.shields.io/badge/-Get%20on%20the%20list-red?style=for-the-badge)](#want-to-see-your-name-on-this-list)

![Adversary Lineup](https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/adversary-lineup-2.png)

## Maintainers
The following contributors have demonstrated their passion for the FalconPy project by going above and beyond to assist with the maintenance of this repository.
These coders deserve accolades and laurels as well as cool titles and cartoons. Their efforts have earned them the community's appreciation.

| Name | Role |
| :--- | :--- |
| Šimon L., `@isimluk` | [Sanity Checker](https://xkcd.com/1926/) |
| Josh Lang, `@jlangdev` | [Lint Purveyor](https://xkcd.com/1833/) |
| Gabe Alford, `@redhatrises` | [Git Whisperer](https://xkcd.com/1597/) |
| Brendan Kremian, `@bk-cs` | [Disparate Ringbearer](https://xkcd.com/353/)
| Christophe Viaud, `@falcon-pioupiou` | [Consequence Substantiator](https://xkcd.com/1678/) |
| Shane Shellenbarger, `@soggysec` | [Calamity Validator](https://xkcd.com/1700/) |

## Contributors
The following members of the community have made requests, suggestions, code contributions or provided feedback and reported bugs.
This has been a critical element in the development of the FalconPy project.

![GitHub contributors](https://img.shields.io/github/contributors/CrowdStrike/falconpy?label=code%20contributors&style=for-the-badge)

+ Justin Harris, `@jhseceng`
+ Bryan McClellan, `@mccbryan3`
+ Caleb Schwartz, `@rewgord`
+ Christopher Hammond, `ChristopherHammond13`
+ `@modubyk`
+ James Hodgkinson, `@yaleman`
+ `@matcha-shake`
+ `@nighttardis`
+ Andrew, `@aneisch`
+ Sean Whalen, `@cah-sean-whalen`
+ `@woodtechie1428`
+ `@sshahar`
+ Chris S, `@EdgeSync`
+ Alexandre Borgo, `@alexandreborgo`
+ Kyle Cozad, `@cozadk`
+ `@sspencer-hubble`
+ Timothy Sullivan, `@tsullivan06`
+ `@t-lark`
+ Steve Klassen, `@mrxinu`
+ Valerian Rossigneux, `@valerianrossigneux`
+ Kenny Mancuso, `@KennyOps`
+ `@morcef`
+ Andrew Harris, `@ciberesponce`
+ `@philldtaylor`
+ Kevin K. Kragh, `@kra-ts`
+ `@mwb8`

## Sponsors
Without the support of these executives, the FalconPy project would not have happened.

| Name | Role |
| :-- | :-- |
| Chris Kachigian, `@ckachigian` | Herder of Cats |
| Rekha Das | Gatekeeper |
| Robbie Coleman, `@erraggy` | Keymaster |
| Mike Cryer | Colonel-in-Chief |

#### Honorable mentions
+ Jaime Franklin, `@franklinjff`
+ Shawn Wells, `@shawndwells`


# Want to see your name on this list?
Join an elite community of security-focused Python coders and help **stop breaches**.

We want your contributions!

### Start [here](https://github.com/CrowdStrike/falconpy/blob/main/CONTRIBUTING.md).

---


<p align="center"><img src="https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/cs-logo-footer.png"><BR/><img width="350px" src="https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/cs-adversaries-group.png"></P>
<h3><P align="center">WE STOP BREACHES</P></h3>

==> crowdstrike_falconpy_dev-1.2.3.dev1-py3-none-any.whl: crowdstrike_falconpy_dev-1.2.3.dev1.dist-info/AUTHORS.md <==
![CrowdStrike FalconPy](https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/cs-logo.png)

[![Twitter URL](https://img.shields.io/twitter/url?label=Follow%20%40CrowdStrike&style=social&url=https%3A%2F%2Ftwitter.com%2FCrowdStrike)](https://twitter.com/CrowdStrike)

# FalconPy Project Authors
The FalconPy project exists to enable developer interactions with the CrowdStrike Falcon API. Designed to be easy to integrate and use within your Python projects, the library is released under the [Unlicense](LICENSE) license. Developed and maintained by a diverse group of security architects, engineers and specialists, FalconPy has received multiple contributions from the community at large.

| Name | |
| :--- | :--- |
| Joshua Hiller, `@jshcodes` | [Lord of the FalconPys](https://xkcd.com/1604/) [:fly:](https://xkcd.com/1856/) |
| Dixon Styres, `@crowdstrikedcs` | [Author](https://xkcd.com/1646/) |
| Devin Cargill, `@dcargs` | [Author](https://xkcd.com/722/) |

<BR/>

[![Maintainers](https://img.shields.io/badge/-Maintainers-lightgreen?style=for-the-badge)](#maintainers)
[![Contributors](https://img.shields.io/badge/-Contributors-tan?style=for-the-badge)](#contributors)
[![Sponsors](https://img.shields.io/badge/-Sponsors-silver?style=for-the-badge)](#sponsors)
[![Get on the list](https://img.shields.io/badge/-Get%20on%20the%20list-red?style=for-the-badge)](#want-to-see-your-name-on-this-list)

![Adversary Lineup](https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/adversary-lineup-2.png)

## Maintainers
The following contributors have demonstrated their passion for the FalconPy project by going above and beyond to assist with the maintenance of this repository.
These coders deserve accolades and laurels as well as cool titles and cartoons. Their efforts have earned them the community's appreciation.

| Name | Role |
| :--- | :--- |
| Šimon L., `@isimluk` | [Sanity Checker](https://xkcd.com/1926/) |
| Josh Lang, `@jlangdev` | [Lint Purveyor](https://xkcd.com/1833/) |
| Gabe Alford, `@redhatrises` | [Git Whisperer](https://xkcd.com/1597/) |
| Brendan Kremian, `@bk-cs` | [Disparate Ringbearer](https://xkcd.com/353/)
| Christophe Viaud, `@falcon-pioupiou` | [Consequence Substantiator](https://xkcd.com/1678/) |
| Shane Shellenbarger, `@soggysec` | [Calamity Validator](https://xkcd.com/1700/) |
| Timothy Sullivan, `@tsullivan06` | [Functionality Determinator](https://xkcd.com/1349/) |
| Steve Klassen, `@mrxinu` | [Dilemma Respondent](https://xkcd.com/85/) |

## Contributors
The following members of the community have made requests, suggestions, code contributions or provided feedback and reported bugs.
This has been a critical element in the development of the FalconPy project.

![GitHub contributors](https://img.shields.io/github/contributors/CrowdStrike/falconpy?label=code%20contributors&style=for-the-badge)

+ Justin Harris, `@jhseceng`
+ Bryan McClellan, `@mccbryan3`
+ Caleb Schwartz, `@rewgord`
+ Christopher Hammond, `@ChristopherHammond13`
+ `@modubyk`
+ James Hodgkinson, `@yaleman`
+ `@matcha-shake`
+ `@nighttardis`
+ Andrew, `@aneisch`
+ Sean Whalen, `@cah-sean-whalen`
+ `@woodtechie1428`
+ `@sshahar`
+ Chris S, `@EdgeSync`
+ Alexandre Borgo, `@alexandreborgo`
+ Kyle Cozad, `@cozadk`
+ `@sspencer-hubble`
+ `@t-lark`
+ Valerian Rossigneux, `@valerianrossigneux`
+ Kenny Mancuso, `@KennyOps`
+ `@morcef`
+ Andrew Harris, `@ciberesponce`
+ `@philldtaylor`
+ Kevin K. Kragh, `@kra-ts`
+ `@mwb8`
+ `@TheITSecurityGuy`
+ Ray Heffer, `@rayheffer`
+ Philip Scheidl, `@wozboz`
+ `@micgoetz`
+ Hod Alpert, `@hod-alpert`
+ `@mwilco03`
+ Glenn, `@hiddenillusion`
+ Taylor Trueblood, `@Trueblood506`

## Sponsors
Without the support of these executives, the FalconPy project would not have happened.

| Name | Role |
| :-- | :-- |
| Chris Kachigian, `@ckachigian` | Herder of Cats |
| Rekha Das | Gatekeeper |
| Robbie Coleman, `@erraggy` | Keymaster |
| Mike Cryer | Colonel-in-Chief |

#### Honorable mentions
+ Jaime Franklin, `@franklinjff`
+ Shawn Wells, `@shawndwells`


# Want to see your name on this list?
Join an elite community of security-focused Python coders and help **stop breaches**.

We want your contributions!

### Start [here](https://github.com/CrowdStrike/falconpy/blob/main/CONTRIBUTING.md).

---


<p align="center"><img src="https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/cs-logo-footer.png"><BR/><img width="350px" src="https://raw.githubusercontent.com/CrowdStrike/falconpy/main/docs/asset/cs-adversaries-group.png"></P>
<h3><P align="center">WE STOP BREACHES</P></h3>
